@@ -4,8 +4,6 @@ parameter_estimates.modsem_da <- function(object, ...) {
 }
 
 
-MODSEM_VERSION <- "1.0.3"
-
 #' summary for modsem objects
 #'
 #' @param object modsem object to summarized
@@ -20,7 +18,8 @@ MODSEM_VERSION <- "1.0.3"
 #' @param loadings print loadings
 #' @param regressions print regressions
 #' @param covariances print covariances
-#' @param intercepts print intercepts
+#' @param intercepts should intercepts be included in the output?
+#' If `standardized = TRUE` intercepts will by default be excluded. 
 #' @param variances print variances
 #' @param var.interaction if FALSE (default) variances for interaction terms will be removed (if present)
 #' @param ... additional arguments
@@ -43,7 +42,7 @@ MODSEM_VERSION <- "1.0.3"
 #' }
 summary.modsem_da <- function(object,
                               H0 = TRUE,
-                              verbose = TRUE,
+                              verbose = interactive(),
                               r.squared = TRUE,
                               adjusted.stat = FALSE,
                               digits = 3,
@@ -53,14 +52,14 @@ summary.modsem_da <- function(object,
                               loadings = TRUE,
                               regressions = TRUE,
                               covariances = TRUE,
-                              intercepts = TRUE,
+                              intercepts = !standardized,
                               variances = TRUE,
                               var.interaction = FALSE,
                               ...) {
   method <- object$method
 
   if (standardized) {
-    parTable <- standardized_estimates(object)
+    parTable <- standardized_estimates(object, intercepts = intercepts)
   } else {
     parTable <- parameter_estimates(object)
   }
@@ -68,7 +67,7 @@ summary.modsem_da <- function(object,
   if (!var.interaction) {
     parTable <- removeInteractionVariances(parTable)
   }
-  
+
   args <- object$args
   out <- list(
     parTable       = parTable,
@@ -81,7 +80,7 @@ summary.modsem_da <- function(object,
     method         = method,
     optimizer      = object$optimizer,
     quad           = object$info.quad,
-    type.se        = object$type.se, 
+    type.se        = object$type.se,
     type.estimates = ifelse(standardized, "standardized", object$type.estimates),
     information    = object$information
   )
@@ -104,7 +103,7 @@ summary.modsem_da <- function(object,
     if (is.null(estH0)) {
       warning2("Comparative fit to H0 will not be calculated.")
       H0        <- FALSE
-      out$D     <- NULL 
+      out$D     <- NULL
       out$fitH0 <- NULL
 
     } else {
@@ -148,34 +147,34 @@ print.summary_da <- function(x, digits = 3, ...) {
                                        covariances = x$format$covariances,
                                        intercepts = x$format$intercepts,
                                        variances = x$format$variances)
-  cat(paste0("\nmodsem (version ", MODSEM_VERSION, "):\n"))
-  names <- c("Estimator", "Optimization method", "Number of observations", 
-             "Number of iterations", "Loglikelihood", 
+  cat(paste0("\nmodsem (version ", PKG_INFO$version, "):\n"))
+  names <- c("Estimator", "Optimization method", "Number of observations",
+             "Number of iterations", "Loglikelihood",
              "Akaike (AIC)", "Bayesian (BIC)")
-  values <- c(stringr::str_to_upper(c(x$method, x$optimizer)), 
-              x$N, x$iterations, round(x$logLik, 2), round(x$fit$AIC, 2), 
+  values <- c(stringr::str_to_upper(c(x$method, x$optimizer)),
+              x$N, x$iterations, round(x$logLik, 2), round(x$fit$AIC, 2),
               round(x$fit$BIC, 2))
   if (x$format$adjusted.stat) {
     names  <- c(names, "Corrected Akaike (AICc)", "Adjusted Bayesian (aBIC)")
     values <- c(values, round(x$fit$AICc, 2), round(x$fit$aBIC, 2))
   }
 
-  cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+  cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                    width.out = width.out), "\n")
-  
+
   if (!is.null(x$quad)) {
     cat("Numerical Integration:\n")
     names <- c("Points of integration (per dim)", "Dimensions",
                "Total points of integration")
     values <- c(x$quad$nodes.dim, x$quad$dim, x$quad$nodes.total)
-    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                      width.out = width.out), "\n")
 
   }
 
   if (!is.null(x$D)) {
     cat("Fit Measures for H0:\n")
-    names <- c("Loglikelihood", "Akaike (AIC)", "Bayesian (BIC)") 
+    names <- c("Loglikelihood", "Akaike (AIC)", "Bayesian (BIC)")
     values <- c(round(x$nullModel$logLik), round(x$fitH0$AIC, 2), round(x$fitH0$BIC, 2))
 
     if (x$format$adjusted.stat) {
@@ -183,24 +182,24 @@ print.summary_da <- function(x, digits = 3, ...) {
       values <- c(values, round(x$fitH0$AICc, 2), round(x$fitH0$aBIC, 2))
     }
 
-    names <- c(names, "Chi-square", "Degrees of Freedom (Chi-square)", 
+    names <- c(names, "Chi-square", "Degrees of Freedom (Chi-square)",
                "P-value (Chi-square)", "RMSEA")
-    values <- c(values, formatNumeric(x$fitH0$chisq.value, digits = 2), 
+    values <- c(values, formatNumeric(x$fitH0$chisq.value, digits = 2),
                 x$fitH0$chisq.df,
                 formatPval(x$fitH0$chisq.pvalue, scientific = x$format$scientific),
                 formatNumeric(x$fitH0$RMSEA, digits = 3))
-    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                      width.out = width.out), "\n")
 
     cat("Comparative fit to H0 (no interaction effect)\n")
-    names <- c("Loglikelihood change", 
-               "Difference test (D)", 
+    names <- c("Loglikelihood change",
+               "Difference test (D)",
                "Degrees of freedom (D)", "P-value (D)")
-    values <- c(formatNumeric(x$D$llChange, digits = 2), 
+    values <- c(formatNumeric(x$D$llChange, digits = 2),
                 formatNumeric(x$D$D, digits = 2),
-                x$D$df, 
+                x$D$df,
                 formatPval(x$D$p, scientific = x$format$scientific))
-    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                      width.out = width.out), "\n")
 
   }
@@ -209,23 +208,23 @@ print.summary_da <- function(x, digits = 3, ...) {
     r.squared <- x$r.squared
     r.squared$Rsqr <- formatNumeric(r.squared$Rsqr, digits = 3)
     maxWidth <- max(vapply(r.squared$Rsqr, FUN.VALUE = numeric(1), FUN = nchar))
-    r.squared$Rsqr <- 
+    r.squared$Rsqr <-
       stringr::str_pad(r.squared$Rsqr, width = maxWidth, side = "left")
 
     cat("R-Squared:\n")
     names <- r.squared$eta
-    values <- character(length(names)) 
+    values <- character(length(names))
     for (i in seq_along(r.squared$eta)) {
       values[[i]] <- r.squared$Rsqr[[i]]
     }
-    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+    cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                      width.out = width.out))
 
     if (!is.null(r.squared$H0)) {
       r.squared$H0$Rsqr <- formatNumeric(r.squared$H0$Rsqr, digits = 3)
-      maxWidth <- 
+      maxWidth <-
         max(vapply(r.squared$H0$Rsqr, FUN.VALUE = numeric(1), FUN = nchar))
-      r.squared$H0$Rsqr <- 
+      r.squared$H0$Rsqr <-
         stringr::str_pad(r.squared$H0$Rsqr, width = maxWidth, side = "left")
 
       cat("R-Squared Null-Model (H0):\n")
@@ -233,17 +232,17 @@ print.summary_da <- function(x, digits = 3, ...) {
       for (i in seq_along(names)) {
           values[[i]] <- formatNumeric(r.squared$H0$Rsqr[[i]], digits = 3)
       }
-      cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+      cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                        width.out = width.out))
 
       # Calculate Change (using unformatted Rsquared)
-      r.squared$H0$diff <- 
+      r.squared$H0$diff <-
         formatNumeric(x$r.squared$Rsqr - x$r.squared$H0$Rsqr, digits = 3)
       cat("R-Squared Change:\n")
       for (i in seq_along(names)) {
         values[[i]] <- r.squared$H0$diff[[i]]
       }
-      cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+      cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                        width.out = width.out))
     }
   }
@@ -251,7 +250,7 @@ print.summary_da <- function(x, digits = 3, ...) {
   cat("\nParameter Estimates:\n")
   names <- c("Coefficients", "Information", "Standard errors")
   values <- c(x$type.estimates, x$information, x$type.se)
-  cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ", 
+  cat(allignLhsRhs(lhs = names, rhs = values, pad = "  ",
                    width.out = width.out), "\n")
 
   printParTable(x$parTable,
@@ -272,7 +271,7 @@ print.modsem_da <- function(x, digits = 3, ...) {
   parTable$p.value <- format.pval(parTable$p.value, digits = digits)
   names(parTable)  <- c("lhs", "op", "rhs", "label", "est", "std.error",
                         "z.value", "p.value", "ci.lower", "ci.upper")
-  est <- lapply(parTable, FUN = function(col) 
+  est <- lapply(parTable, FUN = function(col)
                 if (is.numeric(col)) round(col, digits) else col) |>
     as.data.frame()
   print(est)
@@ -296,13 +295,13 @@ estimateNullModel <- function(parTable,
 
     syntax <- parTableToSyntax(strippedParTable)
     if (verbose) cat("Estimating null model\n")
-    modsem_da(syntax, data = data, 
-              method = method, 
-              verbose = verbose, 
-              cov.syntax = cov.syntax, 
-              calc.se = calc.se, 
+    modsem_da(syntax, data = data,
+              method = method,
+              verbose = verbose,
+              cov.syntax = cov.syntax,
+              calc.se = calc.se,
               double = double,
-              standardize = standardize, 
+              standardize = standardize,
               standardize.out = standardize.out,
               mean.observed = mean.observed, ...)
   },
@@ -321,9 +320,9 @@ estimateNullModel <- function(parTable,
 #' null hypothesis model
 #' @param estH1 object of class `modsem_da` representing the
 #' @description Compare the fit of two models using the likelihood ratio test.
-#' `estH0` representing the null 
-#' hypothesis model, and `estH1` the alternative hypothesis model. Importantly, 
-#' the function assumes that `estH0` does not have more free parameters 
+#' `estH0` representing the null
+#' hypothesis model, and `estH1` the alternative hypothesis model. Importantly,
+#' the function assumes that `estH0` does not have more free parameters
 #' (i.e., degrees of freedom) than `estH1`.
 #' alternative hypothesis model
 #' @rdname compare_fit
@@ -388,31 +387,31 @@ calcRsquared <- function(parTable) {
 
 #' @export
 var_interactions.modsem_da <- function(object, ...) {
-  var_interactions.data.frame(parameter_estimates(object))
+  var_interactions.data.frame(parameter_estimates(object), ...)
 }
 
 
-#' @export 
+#' @export
 standardized_estimates.modsem_da <- function(object, ...) {
-  standardized_estimates.data.frame(parameter_estimates(object))
+  standardized_estimates.data.frame(parameter_estimates(object), ...)
 }
 
 
-#' @export 
+#' @export
 modsem_inspect.modsem_da <- function(object, what = NULL, ...) {
   if (is.null(what)) what <- "default"
   modsem_inspect_da(object, what = what, ...)
 }
 
 
-#' @export 
+#' @export
 #' @importFrom stats vcov
 vcov.modsem_da <- function(object, ...) {
   modsem_inspect_da(object, what = "vcov")[[1]]
 }
 
 
-#' @export 
+#' @export
 #' @importFrom stats coefficients
 coefficients.modsem_da <- function(object, type = "all", ...) {
   what <- ifelse(type == "all", yes = "all.coefficients",
@@ -421,7 +420,7 @@ coefficients.modsem_da <- function(object, type = "all", ...) {
 }
 
 
-#' @export 
+#' @export
 #' @importFrom stats coef
 coef.modsem_da <- function(object, type = "all", ...) {
   coefficients.modsem_da(object, type = type, ...)
@@ -432,7 +431,7 @@ coef.modsem_da <- function(object, type = "all", ...) {
 #'
 #' @param object fittet model to inspect
 #' @param ... additional arguments
-#' @description wrapper for vcov, to be used with modsem::vcov_modsem_da, 
+#' @description wrapper for vcov, to be used with modsem::vcov_modsem_da,
 #' since vcov is not in the namespace of modsem, but stats
 #' @export
 vcov_modsem_da <- function(object, ...) {
@@ -444,7 +443,7 @@ vcov_modsem_da <- function(object, ...) {
 #'
 #' @param object fittet model to inspect
 #' @param ... additional arguments
-#' @description wrapper for coef, to be used with modsem::coef_modsem_da, 
+#' @description wrapper for coef, to be used with modsem::coef_modsem_da,
 #' since coef is not in the namespace of modsem, but stats
 #' @export
 coef_modsem_da <- function(object, ...) {
