@@ -1,43 +1,54 @@
-# Functions for tracing paths in SEMs, used both for calculating (co-)variances, 
+# Functions for tracing paths in SEMs, used both for calculating (co-)variances,
 # as well as calculating formulas for (co-)variances.
-prepParTable <- function(pt, addCovPt = TRUE, maxlen = 100) {
+prepParTable <- function(parTable, addCovPt = TRUE, maxlen = 100) {
   # Remove any potential ':' from the model
-  pt <- lapplyDf(pt, stringr::str_remove_all, pattern = ":")
-  structuralVars <- pt[pt$op == "~", c("lhs", "rhs")] |>
-    unlist() |> unique() 
-  pt <- pt[pt$lhs %in% structuralVars & pt$rhs %in% structuralVars, ]
-  pt$mod[pt$mod == ""] <- apply(pt[pt$mod == "", c("lhs", "op", "rhs")],
-                                MARGIN = 1, FUN = stringr::str_c, collapse = "")
+  parTable <- lapplyDf(parTable, stringr::str_remove_all, pattern = ":")
+
+  # get relevant variables
+  structuralVars <- parTable[parTable$op == "~", c("lhs", "rhs")] |>
+    unlist() |> c(getLVs(parTable)) |> unique()
+
+  parTable <- parTable[(parTable$lhs %in% structuralVars & 
+                       parTable$rhs %in% structuralVars) |
+                       parTable$op == "~~", ]
+  # redefine higher order (i.e.,`=~` -> `~`)
+  if (any(parTable$op == "=~")) parTable <- redefineMeasurementModel(parTable)
+
+  # add missing labels
+  labels <- apply(parTable[parTable$mod == "", c("lhs", "op", "rhs")],
+                  MARGIN = 1, FUN = stringr::str_c, collapse = "")
+  parTable[parTable$mod == "", "mod"] <- labels
+
   if (addCovPt) {
-    reversedCovPaths <- pt[pt$lhs != pt$rhs & pt$op == "~~", ] 
+    reversedCovPaths <- parTable[parTable$lhs != parTable$rhs & parTable$op == "~~", ]
     colnames(reversedCovPaths) <- c("rhs", "op", "lhs", "mod")
-    pt <- rbind(pt, reversedCovPaths)
+    parTable <- rbind(parTable, reversedCovPaths)
   }
 
-  pt
+  parTable
 }
 
 
-tracePathsRecurively = function(x, y, pt, maxlen, currentPath = c(), 
+tracePathsRecurively = function(x, y, pt, maxlen, currentPath = c(),
                                 covCount = 0, from = "lhs", depth = 1) {
   if (depth > maxlen) {
     warning2("Encountered a non-recursive model (infinite loop) when tracing paths")
     return(NULL)
-  } 
+  }
 
   if (covCount > 1) return(NULL)
   if (x == y && from == "rhs") return(list(currentPath))
 
   branches <- pt[pt[[from]] == x, ]
   if (NROW(branches) == 0) return(NULL)
-  
+
   paths <- list()
   for (i in seq_len(nrow(branches))) {
     branch       <- branches[i, ]
     nextFrom     <- from
     nextCovCount <- covCount
     nextVar <- ifelse(from == "lhs", yes = branch$rhs, no = branch$lhs)
-      
+
     # reverse direction of travel if covariance (but not before selecting next variable)
     if (branch$op == "~~") {
       nextCovCount <- covCount + 1
@@ -46,11 +57,11 @@ tracePathsRecurively = function(x, y, pt, maxlen, currentPath = c(),
 
     newPaths <- tracePathsRecurively(x = nextVar, y = y, pt = pt, maxlen = maxlen,
                                      currentPath = c(currentPath, branch$mod),
-                                     covCount = nextCovCount, 
+                                     covCount = nextCovCount,
                                      from = nextFrom, depth = depth + 1)
     paths <- c(paths, newPaths)
 
-  } 
+  }
   paths
 }
 
@@ -58,13 +69,13 @@ tracePathsRecurively = function(x, y, pt, maxlen, currentPath = c(),
 cleanTracedPaths <- function(paths) {
   squaredExprs <- purrr::map_chr(paths, function(x) {
      reps <- as.data.frame(table(sort(x)))
-     dplyr::if_else(reps[[2]] > 1, 
+     dplyr::if_else(reps[[2]] > 1,
                     true = paste(reps[[1]], reps[[2]], sep = " ^ "),
                     false = reps[[1]]) |>
      stringr::str_c(collapse = " * ")
   })
   reps <- as.data.frame(table(squaredExprs))
-  dplyr::if_else(reps[[2]] > 1, 
+  dplyr::if_else(reps[[2]] > 1,
                  true = paste(reps[[2]], reps[[1]], sep = " * "),
                  false = reps[[1]]) |>
   stringr::str_c(collapse = " + ")
@@ -73,8 +84,8 @@ cleanTracedPaths <- function(paths) {
 
 generateSyntax <- function(x, y, pt, maxlen = 100, parenthesis = TRUE, ...) {
   pt    <- prepParTable(pt, ...)
-  paths <- tracePathsRecurively(x = x, y = y, pt = pt, maxlen = maxlen) 
-  
+  paths <- tracePathsRecurively(x = x, y = y, pt = pt, maxlen = maxlen)
+
   if (!length(paths)) return(NA)
   cleaned <- cleanTracedPaths(paths)
   if (parenthesis) cleaned <- paste0("(", cleaned, ")")
@@ -92,7 +103,7 @@ addMissingCovariances <- function(pt) {
     cxis <- getUniqueCombos(xis, match = TRUE)
     phi  <- data.frame(lhs = cxis[[1]], op = "~~", rhs = cxis[[2]], mod = "")
   } else phi <- NULL
-  
+
   etas <- getEtas(pt, checkAny = FALSE, isLV = FALSE)
   if (length(etas)) {
     psi  <- data.frame(lhs = etas, op = "~~", rhs = etas, mod = "")
@@ -106,7 +117,7 @@ addMissingCovariances <- function(pt) {
     if (isRowInParTable(row = row, pt = pt, ignore = "mod")) next
     pt <- rbind(pt, row)
   }
-  
+
   pt
 }
 
@@ -123,12 +134,12 @@ addMissingCovariances <- function(pt) {
 #' @param ... Additional arguments passed to \link{trace_path}
 #'
 #' @return A string with the estimated path (simplified if possible)
-#' @export 
+#' @export
 #' @description
-#' This function estimates the path from \code{x} to \code{y} using the path tracing rules. 
-#' Note that it only works with structural parameters, so \code{"=~"} are ignored, unless 
+#' This function estimates the path from \code{x} to \code{y} using the path tracing rules.
+#' Note that it only works with structural parameters, so \code{"=~"} are ignored, unless
 #' \code{measurement.model = TRUE}.
-#' If you want to use the measurement model, 
+#' If you want to use the measurement model,
 #' \code{"~"} should be in the \code{mod} column of \code{pt}.
 #' @examples
 #' library(modsem)
@@ -145,14 +156,7 @@ addMissingCovariances <- function(pt) {
 #' trace_path(pt, x = "Y", y = "Y", missing.cov = TRUE) # variance of Y
 trace_path <- function(pt, x, y, parenthesis = TRUE, missing.cov = FALSE,
                        measurement.model = FALSE, maxlen = 100, ...) {
-  if (measurement.model) {
-    measurmentRows         <- pt$op == "=~"
-    measurmentRowsRhs      <- pt$rhs[measurmentRows]
-    measurmentRowsLhs      <- pt$lhs[measurmentRows]
-    pt$op[measurmentRows]  <- "~"
-    pt$lhs[measurmentRows] <- measurmentRowsRhs 
-    pt$rhs[measurmentRows] <- measurmentRowsLhs
-  }
+  if (measurement.model) pt <- redefineMeasurementModel(pt)
   if (missing.cov) pt <- addMissingCovariances(pt)
   generateSyntax(x = x, y = y, pt = pt, maxlen = maxlen, parenthesis = parenthesis, ...)
 }
